summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2022-08-13 19:58:58 +0000
committerMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2022-08-13 19:58:58 +0000
commit59018635e80700eaecd9c0f388b850cac276809b (patch)
treeadbf7b02f13d96b03a299e5f6a845efae3eafdcc
parent25370095067f19290f7468c4b699cd269785b89d (diff)
round-robin.sh: Rename base-artifacts/baseline to base-artifacts/git
... which better reflects the purpose of the directory. Change-Id: I34c61038175e04828dc57ac0e664d2042c8c468c
-rw-r--r--round-robin.sh20
1 files changed, 10 insertions, 10 deletions
diff --git a/round-robin.sh b/round-robin.sh
index af8c4030..720e0e8d 100644
--- a/round-robin.sh
+++ b/round-robin.sh
@@ -138,12 +138,12 @@ reset_artifacts ()
rr[base-artifacts_rev]=$(git -C base-artifacts rev-parse HEAD)
EOF
- if ! [ -d base-artifacts/baseline/ ]; then
+ if ! [ -d base-artifacts/git/ ]; then
# E.g., we are in "init" mode of update_baseline.
- mkdir base-artifacts/baseline
+ mkdir base-artifacts/git
# Transitional workaround
# Extract baseline from manifest of baseline build
(
local components c
components="${rr[components]}"
@@ -159,7 +159,7 @@ EOF
source base-artifacts/jenkins/manifest.sh
else
# We are in "init" baseline build, apparently.
# Do nothing and hope get_baseline() is not called.
exit 0
fi
@@ -168,9 +168,9 @@ EOF
echo "${rr[${c}_url]}"
else
print_baseline_repo "$project" true
- fi > base-artifacts/baseline/${c}_url
+ fi > base-artifacts/git/${c}_url
- echo "${rr[${c}_rev]}" > base-artifacts/baseline/${c}_rev
+ echo "${rr[${c}_rev]}" > base-artifacts/git/${c}_rev
done
)
fi
@@ -179,7 +179,7 @@ EOF
# of various components.
# Note that we need to copy the whole directory to correctly handle
# builds that fail before all their components are checked out.
- rsync -a base-artifacts/baseline/ ${rr[top_artifacts]}/baseline/
+ rsync -a base-artifacts/git/ ${rr[top_artifacts]}/git/
)
}
@@ -188,8 +188,8 @@ get_baseline_git ()
(
set -euf -o pipefail
assert_with_msg "ERROR: No $1 in baseline git" \
- [ -f "base-artifacts/baseline/$1" ]
- cat "base-artifacts/baseline/$1"
+ [ -f "base-artifacts/git/$1" ]
+ cat "base-artifacts/git/$1"
)
}
@@ -197,7 +197,7 @@ set_current_git ()
{
(
set -euf -o pipefail
- cat > "${rr[top_artifacts]}/baseline/$1"
+ cat > "${rr[top_artifacts]}/git/$1"
)
}
@@ -138,12 +138,12 @@ reset_artifacts ()
# Transitional workaround
- # Extract baseline from manifest of baseline build
+ # Extract baseline git from manifest of baseline build
(
local components c
@@ -159,7 +159,7 @@ EOF
else
# We are in "init" baseline build, apparently.
- # Do nothing and hope get_baseline() is not called.
+ # Do nothing and hope get_baseline_git() is not called.
exit 0
fi